import { n as HighlighterCoreOptions, m as ShikiContext, H as HighlighterGeneric, o as BundledHighlighterOptions, L as LanguageInput, i as ThemeInput, C as CodeToHastOptions, R as Root, b as RequireKeys, c as CodeToThemedTokensOptions, T as ThemedToken, d as CodeToTokensWithThemesOptions, h as MaybeArray, Q as Element, v as ThemeRegistrationRaw, w as ThemeRegistration } from './types/langs.mjs';
export { A as AnsiLanguage, f as Awaitable, B as BuiltinLanguage, a as BuiltinTheme, u as CodeOptionsMeta, s as CodeOptionsMultipleThemes, r as CodeOptionsSingleTheme, t as CodeOptionsThemes, q as CodeToHastOptionsCommon, F as FontStyle, D as HtmlRendererOptions, z as HtmlRendererOptionsCommon, e as IGrammar, I as IRawGrammar, p as LanguageRegistration, M as MaybeGetter, g as MaybeModule, P as PlainTextLanguage, k as ResolveBundleKey, y as ShikijiTransformer, x as ShikijiTransformerContext, S as SpecialLanguage, j as StringLiteralUnion, G as ThemedTokenExplanation, E as ThemedTokenScopeExplanation, l as loadWasm } from './types/langs.mjs';

/**
 * Get the minimal shiki context for rendering.
 */
declare function getShikiContext(options?: HighlighterCoreOptions): Promise<ShikiContext>;

type HighlighterCore = HighlighterGeneric<never, never>;
declare function getHighlighterCore(options?: HighlighterCoreOptions): Promise<HighlighterCore>;

type GetHighlighterFactory<L extends string, T extends string> = (options?: BundledHighlighterOptions<L, T>) => Promise<HighlighterGeneric<L, T>>;
/**
 * Create a `getHighlighter` function with bundled themes and languages.
 *
 * @param bundledLanguages
 * @param bundledThemes
 * @param ladWasm
 */
declare function createdBundledHighlighter<BundledLangs extends string, BundledThemes extends string>(bundledLanguages: Record<BundledLangs, LanguageInput>, bundledThemes: Record<BundledThemes, ThemeInput>, ladWasm: HighlighterCoreOptions['loadWasm']): GetHighlighterFactory<BundledLangs, BundledThemes>;
declare function createSingletonShorthands<L extends string, T extends string>(getHighlighter: GetHighlighterFactory<L, T>): {
    getSingletonHighlighter: () => Promise<HighlighterGeneric<L, T>>;
    codeToHtml: (code: string, options: CodeToHastOptions<L, T>) => Promise<string>;
    codeToHast: (code: string, options: CodeToHastOptions<L, T>) => Promise<Root>;
    codeToThemedTokens: (code: string, options: RequireKeys<CodeToThemedTokensOptions<L, T>, 'theme' | 'lang'>) => Promise<ThemedToken[][]>;
    codeToTokensWithThemes: (code: string, options: RequireKeys<CodeToTokensWithThemesOptions<L, T>, 'themes' | 'lang'>) => Promise<[color: string, theme: string, tokens: ThemedToken[][]][]>;
};

declare function isPlaintext(lang: string | null | undefined): boolean;
declare function toArray<T>(x: MaybeArray<T>): T[];
declare function isSpecialLang(lang: string): boolean;
declare function addClassToHast(node: Element, className: string | string[]): void;

declare function toShikiTheme(rawTheme: ThemeRegistrationRaw | ThemeRegistration): ThemeRegistration;

export { BundledHighlighterOptions, CodeToHastOptions, CodeToThemedTokensOptions, CodeToTokensWithThemesOptions, type GetHighlighterFactory, type HighlighterCore, HighlighterCoreOptions, HighlighterGeneric, LanguageInput, MaybeArray, RequireKeys, ShikiContext, ThemeInput, ThemeRegistration, ThemeRegistrationRaw, ThemedToken, addClassToHast, createSingletonShorthands, createdBundledHighlighter, getHighlighterCore, getShikiContext, isPlaintext, isSpecialLang, toArray, toShikiTheme };
